@@ -7,7 +7,7 @@
 from splinter.meta import InheritedDocs
 
 
-class CookieManagerAPI(object):
+class CookieManagerAPI(InheritedDocs('_CookieManagerAPI', (object,), {})):
     """
     An API that specifies how a splinter driver deals with cookies.
 
@@ -21,7 +21,6 @@ class CookieManagerAPI(object):
         >>> cookie_manager.add({'name': 'Tony'})
         >>> assert cookie_manager['name'] == 'Tony'
     """
-    __metaclass__ = InheritedDocs
 
     def add(self, cookies):
         """
@@ -52,10 +51,12 @@ class CookieManagerAPI(object):
         """
         raise NotImplementedError
 
-    def all(self):
+    def all(self, verbose=False):
         """
         Returns all of the cookies.
 
+            **Note:** If you're using any webdriver and want more info about the cookie, set the `verbose` parameter to `True` (in other drivers, it won't make any difference). In this case, this method will return a list of dicts, each with one cookie's info.
+
         Examples:
 
             >>> cookie_manager.add({'name': 'Tony'})
