@@ -14,12 +14,17 @@ class WebDriver(BaseWebDriver):
 
     driver_name = "Chrome"
 
-    def __init__(self, user_agent=None, wait_time=2, **kwargs):
+    def __init__(self, user_agent=None, wait_time=2, fullscreen=False,
+                 **kwargs):
+
         options = Options()
 
         if user_agent is not None:
             options.add_argument("--user-agent=" + user_agent)
 
+        if fullscreen:
+            options.add_argument('--kiosk')
+
         self.driver = Chrome(chrome_options=options, **kwargs)
 
         self.element_class = WebDriverElement
