@@ -7,7 +7,7 @@
 import re
 
 from lxml.cssselect import CSSSelector
-from zope.testbrowser.browser import Browser
+from zope.testbrowser.browser import Browser, ListControl
 from splinter.element_list import ElementList
 from splinter.exceptions import ElementDoesNotExist
 from splinter.driver import DriverAPI, ElementAPI
@@ -25,6 +25,11 @@ class CookieManager(CookieManagerAPI):
         self._cookies = browser_cookies
 
     def add(self, cookies):
+        if isinstance(cookies, list):
+            for cookie in cookies:
+                for key, value in cookie.items():
+                    self._cookies[key] = value
+                return
         for key, value in cookies.items():
             self._cookies[key] = value
 
@@ -38,8 +43,11 @@ class CookieManager(CookieManagerAPI):
         else:
             self._cookies.clearAll()
 
-    def all(self):
-        return self._cookies.items()
+    def all(self, verbose=False):
+        cookies = {}
+        for key, value in self._cookies.items():
+            cookies[key] = value
+        return cookies
 
     def __getitem__(self, item):
         return self._cookies[item]
@@ -86,6 +94,10 @@ class ZopeTestBrowser(DriverAPI):
     def quit(self):
         pass
 
+    @property
+    def htmltree(self):
+        return lxml.html.fromstring(self.html.decode('utf-8'))
+
     @property
     def title(self):
         return self._browser.title
@@ -99,13 +111,13 @@ class ZopeTestBrowser(DriverAPI):
         return self._browser.url
 
     def find_option_by_value(self, value):
-        html = lxml.html.fromstring(self.html)
+        html = self.htmltree
         element = html.xpath('//option[@value="%s"]' % value)[0]
         control = self._browser.getControl(element.text)
         return ElementList([ZopeTestBrowserOptionElement(control, self)], find_by="value", query=value)
 
     def find_option_by_text(self, text):
-        html = lxml.html.fromstring(self.html)
+        html = self.htmltree
         element = html.xpath('//option[normalize-space(text())="%s"]' % text)[0]
         control = self._browser.getControl(element.text)
         return ElementList([ZopeTestBrowserOptionElement(control, self)], find_by="text", query=text)
@@ -115,7 +127,7 @@ class ZopeTestBrowser(DriverAPI):
         return self.find_by_xpath(xpath, original_find="css", original_selector=selector)
 
     def find_by_xpath(self, xpath, original_find=None, original_selector=None):
-        html = lxml.html.fromstring(self.html)
+        html = self.htmltree
 
         elements = []
 
@@ -205,7 +217,7 @@ class ZopeTestBrowser(DriverAPI):
         control.add_file(open(file_path), content_type, filename)
 
     def _find_links_by_xpath(self, xpath):
-        html = lxml.html.fromstring(self.html)
+        html = self.htmltree
         links = html.xpath(xpath)
         return ElementList([ZopeTestBrowserLinkElement(link, self) for link in links], find_by="xpath", query=xpath)
 
@@ -303,7 +315,7 @@ class ZopeTestBrowserElement(ElementAPI):
 
     @property
     def outer_html(self):
-        return lxml.html.tostring(self._element, encoding=unicode).strip()
+        return lxml.html.tostring(self._element, encoding='unicode').strip()
 
     @property
     def html(self):
@@ -337,7 +349,10 @@ class ZopeTestBrowserControlElement(ZopeTestBrowserElement):
 
     @property
     def value(self):
-        return self._control.value
+        value = self._control.value
+        if isinstance(self._control, ListControl) and len(value) == 1:
+            return value[0]
+        return value
 
     @property
     def checked(self):
